pub struct TimerEvents { /* private fields */ }Expand description
Subscription handle for timer events.
Implementations
Sourceimpl TimerEvents
impl TimerEvents
Sourcepub fn try_recv(&mut self) -> Option<TimerEvent>
pub fn try_recv(&mut self) -> Option<TimerEvent>
Attempts to receive the next timer event without waiting.
Sourcepub async fn recv(&mut self) -> Option<TimerEvent>
pub async fn recv(&mut self) -> Option<TimerEvent>
Waits for the next timer event.
Sourcepub async fn wait_started(&mut self) -> Option<TimerEvent>
pub async fn wait_started(&mut self) -> Option<TimerEvent>
Waits for the next start event.
Sourcepub async fn wait_tick(&mut self) -> Option<TimerEvent>
pub async fn wait_tick(&mut self) -> Option<TimerEvent>
Waits for the next tick event.
Sourcepub async fn wait_paused(&mut self) -> Option<TimerEvent>
pub async fn wait_paused(&mut self) -> Option<TimerEvent>
Waits for the next paused event.
Sourcepub async fn wait_resumed(&mut self) -> Option<TimerEvent>
pub async fn wait_resumed(&mut self) -> Option<TimerEvent>
Waits for the next resumed event.
Sourcepub async fn wait_finished(&mut self) -> Option<TimerOutcome>
pub async fn wait_finished(&mut self) -> Option<TimerOutcome>
Waits for the next finished event.
Sourcepub async fn wait_stopped(&mut self) -> Option<TimerOutcome>
pub async fn wait_stopped(&mut self) -> Option<TimerOutcome>
Waits for the next finished event with a stopped outcome.
Sourcepub async fn wait_cancelled(&mut self) -> Option<TimerOutcome>
pub async fn wait_cancelled(&mut self) -> Option<TimerOutcome>
Waits for the next finished event with a cancelled outcome.