pub struct TimerStatistics {
pub execution_count: usize,
pub successful_executions: usize,
pub failed_executions: usize,
pub elapsed_time: Duration,
pub last_error: Option<TimerError>,
}Expand description
Statistics for a timer run.
Fields
execution_count: usizeNumber of callback executions attempted during the current run.
successful_executions: usizeNumber of successful callback executions.
failed_executions: usizeNumber of failed callback executions.
elapsed_time: DurationTotal elapsed time since the current run started.
last_error: Option<TimerError>The most recent callback error observed in the current run.