TimerStatistics

Struct TimerStatistics 

pub struct TimerStatistics {
    pub execution_count: usize,
    pub successful_executions: usize,
    pub failed_executions: usize,
    pub elapsed_time: Duration,
    pub last_error: Option<TimerError>,
}
Statistics for a timer run.

Fields

execution_count: usize

Number of callback executions attempted during the current run.

successful_executions: usize

Number of successful callback executions.

failed_executions: usize

Number of failed callback executions.

elapsed_time: Duration

Total elapsed time since the current run started.

last_error: Option<TimerError>

The most recent callback error observed in the current run.